==> bkup_15_7_24.zip: src/resources/views/user/partials/top-bar.blade.php <==

<header class="d-header">
    <div class="container-fluid px-0">
        <div class="row align-items-center">
            <div class="col-lg-5 col-6 d-flex align-items-center">
                <div class="d-header-left">
                    <div class="sidebar-button" id="dash-sidebar-btn">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                </div>
            </div>
            <div class="col-lg-7 col-6">
                <div class="d-header-right d-flex justify-content-end align-items-center">
                    <div class="user-name pr-3">
                        @if (Auth::user()->is_franchisee)
                            <span class="text-primary fw-bold">{{ __('Welcome Franchisee:') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}!</span>
                        @else
                            <span class="text-primary fw-bold">{{ __('Welcome') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}</span>
                        @endif
                    </div>
                    <div class="i-dropdown user-dropdown dropdown">
                        <div class="user-dropdown-meta dropdown-toggle hide-arrow" data-bs-toggle="dropdown">
                            <div class="user-img">
                                <img src="{{ displayImage(Auth::user()->image, '400x400') }}" alt="{{ __('Profile image') }}">
                            </div>
                            <div class="user-dropdown-info">
                                <p>{{ Auth::user()->name }}</p>
                            </div>
                        </div>

                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <span>{{ __('Welcome') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}!</span>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('user.wallet.index') }}">
                                    {{ __('Wallet Top-Up') }}
                                </a>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('logout') }}" onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                    {{ __('Log Out') }}
                                </a>

                                <form id="logout-form" method="POST" action="{{ route('logout') }}">
                                    @csrf
                                </form>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</header>


<!--<header class="d-header">
    <div class="container-fluid px-0">
        <div class="row align-items-center">
            <div class="col-lg-5 col-6 d-flex align-items-center">
                <div class="d-header-left">
                    <div class="sidebar-button" id="dash-sidebar-btn">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                </div>
            </div>
            <div class="col-lg-7 col-6">
                <div class="d-header-right d-flex justify-content-end align-items-center">
                    <div class="user-name pr-3">
                        <span class="text-primary fw-bold">{{ Auth::user()->first_name }}</span>
                        <span class="text-primary fw-bold">{{ Auth::user()->last_name }}</span>
                    </div>
                    <div class="i-dropdown user-dropdown dropdown">
                        <div class="user-dropdown-meta dropdown-toggle hide-arrow" data-bs-toggle="dropdown">
                            <div class="user-img">
                                <img src="{{ displayImage(Auth::user()->image, '400x400') }}" alt="{{ __('Profile image') }}">
                            </div>
                            <div class="user-dropdown-info">
                                <p>{{ Auth::user()->name }}</p>
                            </div>
                        </div>

                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <span>{{ __('Welcome') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}!</span>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('user.wallet.index') }}">
                                    {{ __('Wallet Top-Up') }}
                                </a>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('logout') }}" onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                    {{ __('Log Out') }}
                                </a>

                                <form id="logout-form" method="POST" action="{{ route('logout') }}">
                                    @csrf
                                </form>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</header>
-->

==> bkup_21_07.zip: src/resources/views/user/partials/top-bar.blade.php <==
<header class="d-header" style="{{ Auth::user()->is_franchisee ? 'background-color: var(--color-primary);' : '' }}">
    <div class="container-fluid px-0">
        <div class="row align-items-center">
            <div class="col-lg-5 col-6 d-flex align-items-center">
                <div class="d-header-left">
                    <div class="sidebar-button" id="dash-sidebar-btn">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                </div>
            </div>
            <div class="col-lg-7 col-6">
                <div class="d-header-center d-flex justify-content-end align-items-center">
                    <div class="user-name pr-3 text-center text-md-start"> <!-- Center align text on large screens, start on mobile -->
                        @if (Auth::user()->is_franchisee)
                            <span class="text-white fw-bold">{{ __('Welcome Franchisee:') }} <strong>{{ Auth::user()->username }}</strong></span>
                            <span class="fw-bold" style="color: white;"></span> <!-- White "test" text for franchisee -->
                        @else
                            <span class="text-blue fw-bold">{{ __('Welcome') }} {{ Auth::user()->username }}</span>
                            <span class="fw-bold" style="color: blue;"></span> <!-- Blue "test" text for non-franchisee -->
                        @endif
                    </div>
                    <div class="i-dropdown user-dropdown dropdown">
                        <div class="user-dropdown-meta dropdown-toggle hide-arrow" data-bs-toggle="dropdown">
                            <div class="user-img">
                                <img src="{{ displayImage(Auth::user()->image, '400x400') }}" alt="{{ __('Profile image') }}">
                            </div>
                            <div class="user-dropdown-info">
                                <p>{{ Auth::user()->name }}</p>
                            </div>
                        </div>

                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <span>{{ __('Welcome') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}!</span>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('user.wallet.index') }}">
                                    {{ __('Wallet Top-Up') }}
                                </a>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('logout') }}" onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                    {{ __('Log Out') }}
                                </a>

                                <form id="logout-form" method="POST" action="{{ route('logout') }}">
                                    @csrf
                                </form>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</header>





<!--<header class="d-header">
    <div class="container-fluid px-0">
        <div class="row align-items-center">
            <div class="col-lg-5 col-6 d-flex align-items-center">
                <div class="d-header-left">
                    <div class="sidebar-button" id="dash-sidebar-btn">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                </div>
            </div>
            <div class="col-lg-7 col-6">
                <div class="d-header-right d-flex justify-content-end align-items-center">
                    <div class="user-name pr-3">
                        <span class="text-primary fw-bold">{{ Auth::user()->first_name }}</span>
                        <span class="text-primary fw-bold">{{ Auth::user()->last_name }}</span>
                    </div>
                    <div class="i-dropdown user-dropdown dropdown">
                        <div class="user-dropdown-meta dropdown-toggle hide-arrow" data-bs-toggle="dropdown">
                            <div class="user-img">
                                <img src="{{ displayImage(Auth::user()->image, '400x400') }}" alt="{{ __('Profile image') }}">
                            </div>
                            <div class="user-dropdown-info">
                                <p>{{ Auth::user()->name }}</p>
                            </div>
                        </div>

                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <span>{{ __('Welcome') }} {{ Auth::user()->first_name }} {{ Auth::user()->last_name }}!</span>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('user.wallet.index') }}">
                                    {{ __('Wallet Top-Up') }}
                                </a>
                            </li>
                            <li>
                                <a class="dropdown-item" href="{{ route('logout') }}" onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                    {{ __('Log Out') }}
                                </a>

                                <form id="logout-form" method="POST" action="{{ route('logout') }}">
                                    @csrf
                                </form>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</header>
-->
